package cn.com.infosec.crypto.engines;

import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.DataLengthException;
import cn.com.infosec.crypto.params.KeyParameter;

public class DESedeEngine extends DESEngine {
   protected static final int BLOCK_SIZE = 8;
   private int[] workingKey1 = null;
   private int[] workingKey2 = null;
   private int[] workingKey3 = null;
   private boolean forEncryption;

   public void init(boolean encrypting, CipherParameters params) {
      if (params instanceof KeyParameter) {
         byte[] params1;
         byte[] var10000 = params1 = ((KeyParameter)params).getKey();
         byte var3 = 8;
         byte[] var4 = new byte[8];
         byte var5 = 8;
         byte[] var6 = new byte[8];
         byte var7 = 8;
         byte[] var8 = new byte[8];
         if (var10000.length <= 24) {
            this.forEncryption = encrypting;
            if (params1.length == 24) {
               System.arraycopy(params1, 0, var4, 0, var3);
               System.arraycopy(params1, 8, var6, 0, var5);
               System.arraycopy(params1, 16, var8, 0, var7);
               this.workingKey1 = this.generateWorkingKey(encrypting, var4);
               this.workingKey2 = this.generateWorkingKey(encrypting ^ true, var6);
               this.workingKey3 = this.generateWorkingKey(encrypting, var8);
            } else {
               System.arraycopy(params1, 0, var4, 0, var3);
               System.arraycopy(params1, 8, var6, 0, var5);
               this.workingKey1 = this.generateWorkingKey(encrypting, var4);
               this.workingKey2 = this.generateWorkingKey(encrypting ^ true, var6);
               this.workingKey3 = this.workingKey1;
            }

         } else {
            throw new IllegalArgumentException("key size greater than 24 bytes");
         }
      } else {
         throw new IllegalArgumentException("invalid parameter passed to DESede init - " + params.getClass().getName());
      }
   }

   public String getAlgorithmName() {
      return "DESede";
   }

   public int getBlockSize() {
      return 8;
   }

   public int processBlock(byte[] in, int inOff, byte[] out, int outOff) {
      int[] var5;
      if ((var5 = this.workingKey1) != null) {
         if (inOff + 8 <= in.length) {
            if (outOff + 8 <= out.length) {
               if (this.forEncryption) {
                  this.desFunc(var5, in, inOff, out, outOff);
                  this.desFunc(this.workingKey2, out, outOff, out, outOff);
                  this.desFunc(this.workingKey3, out, outOff, out, outOff);
               } else {
                  this.desFunc(this.workingKey3, in, inOff, out, outOff);
                  this.desFunc(this.workingKey2, out, outOff, out, outOff);
                  this.desFunc(this.workingKey1, out, outOff, out, outOff);
               }

               return 8;
            } else {
               throw new DataLengthException("output buffer too short");
            }
         } else {
            throw new DataLengthException("input buffer too short");
         }
      } else {
         throw new IllegalStateException("DESede engine not initialised");
      }
   }

   public void reset() {
   }
}
